@@ -30,38 +30,12 @@
 Standard Routines for working with ssl context creation
 """
 import os
-import sys
 
 from OpenSSL import SSL
 from twisted.internet import error, ssl
 from twisted.python import log
 
-from dirspec.basedir import load_config_paths
-
-
-def get_cert_location():
-    """Return path to certificate files."""
-
-    if sys.platform == "win32":
-        ssl_cert_location = list(load_config_paths(
-                "ubuntuone-storageprotocol"))[0]
-
-    elif sys.platform == "darwin":
-        if getattr(sys, "frozen", None) is not None:
-            main_app_dir = "".join(__file__.partition(".app")[:-1])
-            main_app_resources_dir = os.path.join(main_app_dir,
-                                                  "Contents",
-                                                  "Resources")
-            ssl_cert_location = main_app_resources_dir
-        else:
-            pkg_dir = os.path.dirname(__file__)
-            src_tree_path = os.path.dirname(os.path.dirname(pkg_dir))
-            ssl_cert_location = os.path.join(src_tree_path,
-                                             "data")
-    else:
-        ssl_cert_location = '/etc/ssl/certs'
-
-    return ssl_cert_location
+from ubuntu_sso.utils import get_cert_dir
 
 
 class HostnameVerifyContextFactory(ssl.CertificateOptions):
@@ -93,7 +67,7 @@ class HostnameVerifyContextFactory(ssl.CertificateOptions):
 
 def get_certificates():
     """Get a list of certificate paths."""
-    ssl_cert_location = get_cert_location()
+    ssl_cert_location = get_cert_dir()
     ca_file = ssl.Certificate.loadPEM(file(os.path.join(ssl_cert_location,
                      'UbuntuOne-Go_Daddy_Class_2_CA.pem'), 'r').read())
     ca_file_2 = ssl.Certificate.loadPEM(file(os.path.join(ssl_cert_location,
