@@ -3,7 +3,7 @@
 #
 # Author: Lucio Torre <lucio.torre@canonical.com>
 #
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU Affero General Public License version 3,
@@ -16,6 +16,19 @@
 #
 # You should have received a copy of the GNU Affero General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
 """
 The base classes for the network client and server.
 
@@ -220,8 +233,8 @@ class RequestHandler(Protocol):
                     self.requests[message.id].error(e)
             else:
                 name = protocol_pb2.Message.DESCRIPTOR \
-                     .enum_types_by_name['MessageType'] \
-                     .values_by_number[message.type].name
+                    .enum_types_by_name['MessageType'] \
+                    .values_by_number[message.type].name
 
                 handler = getattr(self, "handle_" + name, None)
                 if handler is not None:
@@ -428,11 +441,11 @@ class Request(object):
     def cancel_filter(self, function):
         """Raises RequestCancelledError if the request is cancelled.
 
-        This methods exists to be used in a addCallback sequence to assure
+        This methods exists to be used in a addCallback sequence to ensure
         that it does not continue if the request is cancelled, like:
 
-        >>> d.addCallback(cancel_filter(foo))
-        >>> d.addCallbacks(done_callback, error_errback)
+        d.addCallback(cancel_filter(foo))
+        d.addCallbacks(done_callback, error_errback)
 
         Note that you may receive RequestCancelledError in your
         'error_errback' func.
